summaryrefslogtreecommitdiff
path: root/Userland/Libraries/LibCrypto
diff options
context:
space:
mode:
authorLinus Groh <mail@linusgroh.de>2021-05-17 17:48:55 +0100
committerLinus Groh <mail@linusgroh.de>2021-05-17 17:48:55 +0100
commit0aab7743436424170d3d3d421e85e7f066d351e9 (patch)
treefc6bbe146b92a0194978d5cb25095a6018dd660a /Userland/Libraries/LibCrypto
parentbebbeda7262d9139ac249387672e567fe3d3791f (diff)
downloadserenity-0aab7743436424170d3d3d421e85e7f066d351e9.zip
Everywhere: Fix a bunch of typos
Diffstat (limited to 'Userland/Libraries/LibCrypto')
-rw-r--r--Userland/Libraries/LibCrypto/ASN1/ASN1.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Userland/Libraries/LibCrypto/ASN1/ASN1.cpp b/Userland/Libraries/LibCrypto/ASN1/ASN1.cpp
index 13712aacce..c7a2c65141 100644
--- a/Userland/Libraries/LibCrypto/ASN1/ASN1.cpp
+++ b/Userland/Libraries/LibCrypto/ASN1/ASN1.cpp
@@ -127,7 +127,7 @@ Optional<Core::DateTime> parse_generalized_time(const StringView& time)
auto month = lexer.consume(2).to_uint();
auto day = lexer.consume(2).to_uint();
auto hour = lexer.consume(2).to_uint();
- Optional<unsigned> minute, seconds, miliseconds, offset_hours, offset_minutes;
+ Optional<unsigned> minute, seconds, milliseconds, offset_hours, offset_minutes;
[[maybe_unused]] bool negative_offset = false;
if (!lexer.is_eof()) {
if (lexer.consume_specific('Z'))
@@ -152,8 +152,8 @@ Optional<Core::DateTime> parse_generalized_time(const StringView& time)
}
if (lexer.consume_specific('.')) {
- miliseconds = lexer.consume(3).to_uint();
- if (!miliseconds.has_value()) {
+ milliseconds = lexer.consume(3).to_uint();
+ if (!milliseconds.has_value()) {
return {};
}
if (lexer.consume_specific('Z'))
@@ -182,7 +182,7 @@ done_parsing:;
if (offset_hours.has_value() || offset_minutes.has_value())
dbgln("FIXME: Implement GeneralizedTime with offset!");
// Unceremonially drop the miliseconds on the floor.
return Core::DateTime::create(year.value(), month.value(), day.value(), hour.value(), minute.value_or(0), seconds.value_or(0));
}
@@ -182,7 +182,7 @@ done_parsing:;
if (offset_hours.has_value() || offset_minutes.has_value())
dbgln("FIXME: Implement GeneralizedTime with offset!");
- // Unceremonially drop the miliseconds on the floor.
+ // Unceremonially drop the milliseconds on the floor.
return Core::DateTime::create(year.value(), month.value(), day.value(), hour.value(), minute.value_or(0), seconds.value_or(0));
}